@@ -171,12 +171,10 @@ class PngStream(RangeStream):
             chunks[chunk_type].append(chunk_info)
         return chunks
 
-    def get_chunk_data(
-        self, chunk_info: PngChunkInfo, zlib_decompress: bool = False
-    ) -> bytes:
+    def get_chunk_data(self, chunk_info: PngChunkInfo) -> bytes:
         self.add(chunk_info.data_range)
         b = self.active_range_response.read()
-        return zlib.decompress(b) if zlib_decompress else b
+        return b
 
     def get_idat_data(self) -> list[int]:
         """
@@ -192,9 +190,10 @@ class PngStream(RangeStream):
         channels = self.data.IHDR.channel_count
         assert height is not None and width is not None and channels is not None
         expected_length = height * (1 + width * channels)
-        b = b"".join(
-            self.get_chunk_data(chunk_info, zlib_decompress=True)
-            for chunk_info in self.chunks["IDAT"]
+        b = zlib.decompress(
+            b"".join(
+                self.get_chunk_data(chunk_info) for chunk_info in self.chunks["IDAT"]
+            )
         )
         if len(b) != expected_length:
             raise ValueError(f"Expected {expected_length} but got {len(b)}")
@@ -228,6 +227,25 @@ class PngStream(RangeStream):
             has_alpha |= self.has_chunk(chunk_type="tRNS")
         return has_alpha
 
+    def any_semitransparent_idat(self, nonzero: bool = True):
+        """
+        Whether there are any non-255 values in the alpha channel of the PNG,
+        determined from IDAT chunk alone. If not, the alpha channel serves no
+        purpose in practice, and the image may be considered non-transparent.
+
+        If ``nonzero`` is True (the default), check for semitransparent, rather
+        than nontransparent values (i.e. ``0 < A < 255`` rather than ``0 <= A < 255``).
+
+        Note: presumes :meth:`~range_streams.codecs.png.PngStream.alpha_as_direct` has
+        already been called, so the image is known to have 4 channels.
+
+        Args:
+          nonzero : Whether to return ``True`` only if the image has 'intermediate'
+                    (between 0 and 255) values, otherwise whether they're below 255.
+        """
+        A = self.get_idat_data()[3::4]  # alpha channel values
+        return any(0 < v < 255 for v in A) if nonzero else any(v < 255 for v in A)
+
     @property
     def channel_count_as_direct(self):
         """
